@@ -29,8 +29,10 @@ class Pyecharts_Var:
 
 # 折线图、面积图；
 class Line_Py(Pyecharts_Var):
-    def __init__(self, title, x_value, y_name, y_value, *args):
+    def __init__(self, title, x_value, y_name, y_value, *args, pos_top='bottom', legend_icon='roundRect'):
         Pyecharts_Var.__init__(self, title, x_value, y_name, y_value, *args)
+        self.pos_top = pos_top
+        self.legend_icon = legend_icon
 
     def line_render_air(self):
         c = Line()
@@ -45,7 +47,7 @@ class Line_Py(Pyecharts_Var):
         c.set_global_opts(
             title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
-            legend_opts=opts.LegendOpts(pos_left="center", pos_top='bottom', legend_icon='circle'),
+            legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon=self.legend_icon),
             yaxis_opts=opts.AxisOpts(
                 type_="value",
                 max_='dataMax',
@@ -86,7 +88,8 @@ class Line_Py(Pyecharts_Var):
         return c
 
     def line_render_qimai(self):
-        c = Line(init_opts=opts.InitOpts(width="1200px", height="400px"))
+        # c = Line(init_opts=opts.InitOpts(width="1200px", height="400px"))
+        c = Line()
         c.add_xaxis(self.x_value)
         c.add_yaxis(
             series_name=self.y_name,
@@ -106,7 +109,7 @@ class Line_Py(Pyecharts_Var):
                 ),
             ),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
-            legend_opts=opts.LegendOpts(pos_left="center", pos_top='bottom', legend_icon='circle'),
+            legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon='circle'),
             yaxis_opts=opts.AxisOpts(
                 type_="value",
                 max_='dataMax',
@@ -212,9 +215,11 @@ class Line_Py(Pyecharts_Var):
 
 # 柱状图；
 class Bar_Py(Pyecharts_Var):
-    def __init__(self, title, x_value, y_name, y_value, reversal_axis=True):
+    def __init__(self, title, x_value, y_name, y_value, reversal_axis=True, pos_top='bottom', legend_icon='roundRect'):
         Pyecharts_Var.__init__(self, title, x_value, y_name, y_value)
         self.reversal_axis = reversal_axis
+        self.pos_top = pos_top
+        self.legend_icon = legend_icon
 
     def bar_render_general(self):
         c = Bar()
@@ -230,7 +235,7 @@ class Bar_Py(Pyecharts_Var):
         c.set_global_opts(
             title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
-            legend_opts=opts.LegendOpts(pos_left="center", pos_top='bottom', legend_icon='circle'),
+            legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon=self.legend_icon),
         )
         for agr_data in self.args:
             c.add_yaxis(agr_data[0], agr_data[1])
@@ -247,7 +252,7 @@ class Bar_Py(Pyecharts_Var):
         c.set_global_opts(
             title_opts=opts.TitleOpts(title=self.title, subtitle=self.subtitle),
             tooltip_opts=opts.TooltipOpts(trigger="axis"),
-            legend_opts=opts.LegendOpts(pos_left="center", pos_top='bottom', legend_icon='circle'),
+            legend_opts=opts.LegendOpts(pos_left="center", pos_top=self.pos_top, legend_icon=self.legend_icon),
             yaxis_opts=opts.AxisOpts(
                 type_="value",
                 max_='dataMax',
@@ -280,11 +285,12 @@ class Bar_Py(Pyecharts_Var):
 
 # 人物/事件关系图；
 class Graph_Py:
-    def __init__(self, title, data_json={}, is_show=False, run_df_data=pd.DataFrame({})):
+    def __init__(self, title, data_json={}, is_show=False, run_df_data=pd.DataFrame({}), pos_top='bottom'):
         self.title = title
         self.is_show = is_show
         self.data_json = data_json
         self.run_df_data = run_df_data
+        self.pos_top = pos_top
 
     def json_format_graph(self, calc_num=100):
         # 格式化字符串；
@@ -329,23 +335,23 @@ class Graph_Py:
         if len(self.data_json) > 0:
             nodes, links, categories = self.data_json
         else:
-            data_json = self.json_format_graph(calc_num=100)
+            data_json = self.json_format_graph(calc_num=calc_num)
             nodes, links, categories = data_json
         # 开始绘图；
         c = (
             Graph()
                 .add(
-                "",
-                nodes,
-                links,
-                categories,
-                repulsion=50,
-                linestyle_opts=opts.LineStyleOpts(curve=0.2),
-                label_opts=opts.LabelOpts(is_show=self.is_show),
-            )
+                    "",
+                    nodes,
+                    links,
+                    categories,
+                    repulsion=50,
+                    linestyle_opts=opts.LineStyleOpts(curve=0.2),
+                    label_opts=opts.LabelOpts(is_show=self.is_show),
+                )
                 .set_global_opts(
-                legend_opts=opts.LegendOpts(is_show=self.is_show),
-                title_opts=opts.TitleOpts(title=self.title),
+                    legend_opts=opts.LegendOpts(is_show=self.is_show, pos_top=self.pos_top),
+                    title_opts=opts.TitleOpts(title=self.title)
             )
         )
         return c
@@ -358,20 +364,20 @@ class TimeLine_Py:
         self.reder_type = render_type
         self.control_position = control_position
 
-    def render_time_air(self, reversal_axis=True):
+    def render_time_air(self, reversal_axis=True, pos_top='top'):
         time_line = Timeline()  # 创建 Timeline对象
 
         # 开始准备画图；
         for run_data in self.data_list:
-            title_text = run_data[0] + '_数据展示'
+            title_text = str(run_data[0]) + '_数据展示'
             run_date = run_data[0]
             x_value = [str(i) for i in run_data[1]]
             y_title = run_data[2]
             y_value = [float(i) for i in run_data[3]]
             if self.reder_type.lower() == 'Bar_Py'.lower():
-                c = Bar_Py(title_text, x_value, y_title, y_value, reversal_axis=reversal_axis).bar_render_general()
+                c = Bar_Py(title_text, x_value, y_title, y_value, reversal_axis=reversal_axis, pos_top=pos_top).bar_render_general()
             else:
-                c = Line_Py(title_text, x_value, y_title, y_value).line_render_air()
+                c = Line_Py(title_text, x_value, y_title, y_value, pos_top=pos_top).line_render_air()
 
             time_line.add(c, run_date)
         # 画好的图加入时间线；
@@ -382,28 +388,30 @@ class TimeLine_Py:
             symbol_size=2,  # 标记大小;
             play_interval=self.play_interval,  # 播放时间间隔；
             control_position=self.control_position,  # 控制位置;
-            linestyle_opts=opts.LineStyleOpts(
-                width=5,
-                type_='dashed',
-                color='rgb(255,0,0,0.5)'
-            ),
-            label_opts=opts.LabelOpts(
-                color='rgb(0,0,255,0.5)',
-                font_size=15,
-                font_style='italic',
-                font_weight='bold',
-                font_family='Time New Roman',
-                position='left',
-                interval=20
-            )
+            # linestyle_opts=opts.LineStyleOpts(
+            #     width=5,
+            #     type_='dashed',
+            #     color='rgb(255,0,0,0.5)'
+            # ),
+            # label_opts=opts.LabelOpts(
+            #     color='rgb(0,0,255,0.5)',
+            #     font_size=15,
+            #     font_style='italic',
+            #     font_weight='bold',
+            #     font_family='Time New Roman',
+            #     position='left',
+            #     interval=20
+            # )
         )
         return time_line
 
 
 # 词云图；
 class WordCloud_Py:
-    def __init__(self, title, *args):
+    def __init__(self, title, *args, is_show=False, pos_top='bottom'):
         self.title = title
+        self.is_show = is_show
+        self.pos_top = pos_top
         self.args = args
 
     def jieba_cut(self, length_num=0):
@@ -426,5 +434,8 @@ class WordCloud_Py:
         self.jieba_cut(length_num)
         c = WordCloud()
         c.add('', self.word_tuple_result, shape=SymbolType.DIAMOND)
-        c.set_global_opts(title_opts=opts.TitleOpts(title=self.title))
+        c.set_global_opts(
+            title_opts=opts.TitleOpts(title=self.title),
+            legend_opts=opts.LegendOpts(is_show=self.is_show)
+        )
         return c
\ No newline at end of file
